@@ -1,9 +1,9 @@
 // ***************************************************************** -*- C++ -*-
-// werror-test.cpp, $Rev: 2016 $
+// werror-test.cpp, $Rev: 3090 $
 // Simple tests for the wide-string error class WError
 
 #include <iostream>
-#include <exiv2/error.hpp>
+#include <exiv2/exiv2.hpp>
 
 int main()
 {
