@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2010 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      actions.cpp
-  Version:   $Rev: 2374 $
+  Version:   $Rev: 3091 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   08-Dec-03, ahu: created
              30-Apr-06, Roger Larsson: Print filename if processing multiple files
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: actions.cpp 2374 2010-11-06 13:53:15Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: actions.cpp 3091 2013-07-24 05:15:04Z robinwmills $")
 
 // *****************************************************************************
 // included header files
@@ -104,11 +104,11 @@ namespace {
      */
     int str2Tm(const std::string& timeStr, struct tm* tm);
 
-    //! Convert a UTC time to a string "YYYY:MM:DD HH:MI:SS", "" on error
+    //! Convert a localtime to a string "YYYY:MM:DD HH:MI:SS", "" on error
     std::string time2Str(time_t time);
 
     //! Convert a tm structure to a string "YYYY:MM:DD HH:MI:SS", "" on error
-    std::string tm2Str(struct tm* tm);
+    std::string tm2Str(const struct tm* tm);
 
     /*!
       @brief Copy metadata from source to target according to Params::copyXyz
@@ -272,11 +272,11 @@ namespace Action {
 
         // MIME type
         printLabel(_("MIME type"));
-        std::cout << image->mimeType() << "\n";
+        std::cout << image->mimeType() << std::endl;
 
         // Image size
         printLabel(_("Image size"));
-        std::cout << image->pixelWidth() << " x " << image->pixelHeight() << "\n";
+        std::cout << image->pixelWidth() << " x " << image->pixelHeight() << std::endl;
 
         if (exifData.empty()) {
             std::cerr << path_ << ": "
@@ -546,12 +546,13 @@ namespace Action {
 
     bool Print::grepTag(const std::string& key)
     {
-        if (Params::instance().keys_.empty()) return true;
-        for (Params::Keys::const_iterator k = Params::instance().keys_.begin();
-             k != Params::instance().keys_.end(); ++k) {
-            if (*k == key) return true;
+        bool result=Params::instance().keys_.empty();
+		if (!result) 
+			for (Params::Keys::const_iterator k = Params::instance().keys_.begin();
+				!result && k != Params::instance().keys_.end(); ++k) {
+					result = key.find(*k) != std::string::npos;
         }
-        return false;
+        return result ;
     }
 
     void Print::printMetadatum(const Exiv2::Metadatum& md, const Exiv2::Image* pImage)
@@ -1565,7 +1566,7 @@ namespace Action {
                       << " " << _("years") << "\n";
             return 1;
         }
-        time_t time = timegm(&tm);
+        time_t time = mktime(&tm);
         time += adjustment_ + dayAdjustment_ * 86400;
         timeStr = time2Str(time);
         if (Params::instance().verbose_) {
@@ -1739,7 +1740,7 @@ namespace {
     int Timestamp::read(struct tm* tm)
     {
         int rc = 1;
-        time_t t = mktime(tm);
+        time_t t = mktime(tm); // interpret tm according to current timezone settings
         if (t != (time_t)-1) {
             rc = 0;
             actime_  = t;
@@ -1783,22 +1784,18 @@ namespace {
         tm->tm_sec = tmp;
 
         // Conversions to set remaining fields of the tm structure
-        time_t time = timegm(tm);
-#ifdef EXV_HAVE_GMTIME_R
-        if (time == (time_t)-1 || gmtime_r(&time, tm) == 0) return 11;
-#else
-        if (time == (time_t)-1 || std::gmtime(&time)  == 0) return 11;
-#endif
+        if (mktime(tm) == (time_t)-1) return 11;
+
         return 0;
     } // str2Tm
 
     std::string time2Str(time_t time)
     {
-        struct tm* tm = gmtime(&time);
+        struct tm* tm = localtime(&time);
         return tm2Str(tm);
     } // time2Str
 
-    std::string tm2Str(struct tm* tm)
+    std::string tm2Str(const struct tm* tm)
     {
         if (0 == tm) return "";
 
@@ -1880,6 +1877,7 @@ namespace {
         catch (const Exiv2::AnyError& e) {
             std::cerr << target <<
                 ": " << _("Could not write metadata to file") << ": " << e << "\n";
+            return 1;
         }
 
         return 0;
