@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2010 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -21,7 +21,7 @@
 /*!
   @file    basicio.hpp
   @brief   Simple binary IO abstraction
-  @version $Rev: 2045 $
+  @version $Rev: 3091 $
   @author  Brad Schick (brad)
            <a href="mailto:brad@robotbattle.com">brad@robotbattle.com</a>
   @date    04-Dec-04, brad: created
@@ -169,7 +169,12 @@ namespace Exiv2 {
           @return 0 if successful;<BR>
               Nonzero if failure;
          */
-        virtual int seek(long offset, Position pos) = 0;
+#if defined(_MSC_VER)
+        virtual int seek(uint64_t offset, Position pos) = 0;
+#else
+		virtual int seek(long offset, Position pos) = 0;
+#endif
+
         /*!
           @brief Direct access to the IO data. For files, this is done by
                  mapping the file into the process's address space; for memory
@@ -424,8 +429,12 @@ namespace Exiv2 {
           @return 0 if successful;<BR>
                  Nonzero if failure;
          */
+#if defined(_MSC_VER)
+        virtual int seek(uint64_t offset, Position pos);
+#else
         virtual int seek(long offset, Position pos);
-        /*!
+#endif
+		/*!
           @brief Map the file into the process's address space. The file must be
                  open before mmap() is called. If the mapped area is writeable,
                  changes may not be written back to the underlying file until
@@ -632,8 +641,12 @@ namespace Exiv2 {
           @return 0 if successful;<BR>
                  Nonzero if failure;
          */
-        virtual int seek(long offset, Position pos);
-        /*!
+#if defined(_MSC_VER)
+        virtual int seek(uint64_t offset, Position pos);
+#else
+		virtual int seek(long offset, Position pos);
+#endif
+		/*!
           @brief Allow direct access to the underlying data buffer. The buffer
                  is not protected against write access in any way, the argument
                  is ignored.
@@ -727,5 +740,4 @@ namespace Exiv2 {
 #endif
 
 }                                       // namespace Exiv2
-
 #endif                                  // #ifndef BASICIO_HPP_
