@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      canonmn.cpp
-  Version:   $Rev: 2604 $
+  Version:   $Rev: 3198 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              David Cannings (dc) <david@edeca.net>
              Andi Clemens (ac) <andi.clemens@gmx.net>
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: canonmn.cpp 2604 2011-09-04 08:10:32Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: canonmn.cpp 3198 2013-11-17 03:18:39Z nkbj $")
 
 // *****************************************************************************
 // included header files
@@ -60,7 +60,7 @@ namespace Exiv2 {
     };
 
     //! Special treatment pretty-print function for non-unique lens ids.
-    std::ostream& printCsLensByFocalLength(std::ostream& os,
+    std::ostream& printCsLensByFocalLengthAndMaxAperture(std::ostream& os,
                                            const Value& value,
                                            const ExifData* metadata);
 
@@ -148,12 +148,139 @@ namespace Exiv2 {
         { 0x2160000, N_("PowerShot SD1000 / Digital IXUS 70 / IXY Digital 10") },
         { 0x2180000, N_("PowerShot A550") },
         { 0x2190000, N_("PowerShot A450") },
+        { 0x2230000, N_("PowerShot G9") },
+        { 0x2240000, N_("PowerShot A650 IS") },
+        { 0x2260000, N_("PowerShot A720 IS") },
+        { 0x2290000, N_("PowerShot SX100 IS") },
+        { 0x2300000, N_("PowerShot SD950 IS / Digital IXUS 960 IS / IXY Digital 2000 IS") },
+        { 0x2310000, N_("PowerShot SD870 IS / Digital IXUS 860 IS / IXY Digital 910 IS") },
+        { 0x2320000, N_("PowerShot SD890 IS / Digital IXUS 970 IS / IXY Digital 820 IS") },
+        { 0x2360000, N_("PowerShot SD790 IS / Digital IXUS 90 IS / IXY Digital 95 IS") },
+        { 0x2370000, N_("PowerShot SD770 IS / Digital IXUS 85 IS / IXY Digital 25 IS") },
+        { 0x2380000, N_("PowerShot A590 IS") },
+        { 0x2390000, N_("PowerShot A580") },
+        { 0x2420000, N_("PowerShot A470") },
+        { 0x2430000, N_("PowerShot SD1100 IS / Digital IXUS 80 IS / IXY Digital 20 IS") },
+        { 0x2460000, N_("PowerShot SX1 IS") },
+        { 0x2470000, N_("PowerShot SX10 IS") },
+        { 0x2480000, N_("PowerShot A1000 IS") },
+        { 0x2490000, N_("PowerShot G10") },
+        { 0x2510000, N_("PowerShot A2000 IS") },
+        { 0x2520000, N_("PowerShot SX110 IS") },
+        { 0x2530000, N_("PowerShot SD990 IS / Digital IXUS 980 IS / IXY Digital 3000 IS") },
+        { 0x2540000, N_("PowerShot SD880 IS / Digital IXUS 870 IS / IXY Digital 920 IS") },
+        { 0x2550000, N_("PowerShot E1") },
+        { 0x2560000, N_("PowerShot D10") },
+        { 0x2570000, N_("PowerShot SD960 IS / Digital IXUS 110 IS / IXY Digital 510 IS") },
+        { 0x2580000, N_("PowerShot A2100 IS") },
+        { 0x2590000, N_("PowerShot A480") },
+        { 0x2600000, N_("PowerShot SX200 IS") },
+        { 0x2610000, N_("PowerShot SD970 IS / Digital IXUS 990 IS / IXY Digital 830 IS") },
+        { 0x2620000, N_("PowerShot SD780 IS / Digital IXUS 100 IS / IXY Digital 210 IS") },
+        { 0x2630000, N_("PowerShot A1100 IS") },
+        { 0x2640000, N_("PowerShot SD1200 IS / Digital IXUS 95 IS / IXY Digital 110 IS") },
+        { 0x2700000, N_("PowerShot G11") },
+        { 0x2710000, N_("PowerShot SX120 IS") },
+        { 0x2720000, N_("PowerShot S90") },
+        { 0x2750000, N_("PowerShot SX20 IS") },
+        { 0x2760000, N_("PowerShot SD980 IS / Digital IXUS 200 IS / IXY Digital 930 IS") },
+        { 0x2770000, N_("PowerShot SD940 IS / Digital IXUS 120 IS / IXY Digital 220 IS") },
+        { 0x2800000, N_("PowerShot A495") },
+        { 0x2810000, N_("PowerShot A490") },
+        { 0x2820000, N_("PowerShot A3100 IS / A3150 IS") },
+        { 0x2830000, N_("PowerShot A3000 IS") },
+        { 0x2840000, N_("PowerShot SD1400 IS / IXUS 130 / IXY 400F") },
+        { 0x2850000, N_("PowerShot SD1300 IS / IXUS 105 / IXY 200F") },
+        { 0x2860000, N_("PowerShot SD3500 IS / IXUS 210 / IXY 10S") },
+        { 0x2870000, N_("PowerShot SX210 IS") },
+        { 0x2880000, N_("PowerShot SD4000 IS / IXUS 300 HS / IXY 30S") },
+        { 0x2890000, N_("PowerShot SD4500 IS / IXUS 1000 HS / IXY 50S") },
+        { 0x2920000, N_("PowerShot G12") },
+        { 0x2930000, N_("PowerShot SX30 IS") },
+        { 0x2940000, N_("PowerShot SX130 IS") },
+        { 0x2950000, N_("PowerShot S95") },
+        { 0x2980000, N_("PowerShot A3300 IS") },
+        { 0x2990000, N_("PowerShot A3200 IS") },
+        { 0x3000000, N_("PowerShot ELPH 500 HS / IXUS 310 HS / IXY 31S") },
         { 0x3010000, N_("PowerShot Pro90 IS") },
+        { 0x3010001, N_("PowerShot A800") },
+        { 0x3020000, N_("PowerShot ELPH 100 HS / IXUS 115 HS / IXY 210F") },
+        { 0x3030000, N_("PowerShot SX230 HS") },
+        { 0x3040000, N_("PowerShot ELPH 300 HS / IXUS 220 HS / IXY 410F") },
+        { 0x3050000, N_("PowerShot A2200") },
+        { 0x3060000, N_("PowerShot A1200") },
+        { 0x3070000, N_("PowerShot SX220 HS") },
+        { 0x3080000, N_("PowerShot G1 X") },
+        { 0x3090000, N_("PowerShot SX150 IS") },
+        { 0x3100000, N_("PowerShot ELPH 510 HS / IXUS 1100 HS / IXY 51S") },
+        { 0x3110000, N_("PowerShot S100 (new)") },
+        { 0x3130000, N_("PowerShot SX40 HS") },
+        { 0x3120000, N_("PowerShot ELPH 310 HS / IXUS 230 HS / IXY 600F") },
+        { 0x3140000, N_("PowerShot ELPH 500 HS / IXUS 320 HS / IXY 32S") },
+        { 0x3160000, N_("PowerShot A1300") },
+        { 0x3170000, N_("PowerShot A810") },
+        { 0x3180000, N_("PowerShot ELPH 320 HS / IXUS 240 HS / IXY 420F") },
+        { 0x3190000, N_("PowerShot ELPH 110 HS / IXUS 125 HS / IXY 220F") },
+        { 0x3200000, N_("PowerShot D20") },
+        { 0x3210000, N_("PowerShot A4000 IS") },
+        { 0x3220000, N_("PowerShot SX260 HS") },
+        { 0x3230000, N_("PowerShot SX240 HS") },
+        { 0x3240000, N_("PowerShot ELPH 530 HS / IXUS 510 HS / IXY 1") },
+        { 0x3250000, N_("PowerShot ELPH 520 HS / IXUS 500 HS / IXY 3") },
+        { 0x3260000, N_("PowerShot A3400 IS") },
+        { 0x3270000, N_("PowerShot A2400 IS") },
+        { 0x3280000, N_("PowerShot A2300") },
+        { 0x3330000, N_("PowerShot G15") },
+        { 0x3340000, N_("PowerShot SX50") },
+        { 0x3350000, N_("PowerShot SX160 IS") },
+        { 0x3360000, N_("PowerShot S110 (new)") },
+        { 0x3370000, N_("PowerShot SX500 IS") },
+        { 0x3380000, N_("PowerShot N") },
+        { 0x3390000, N_("IXUS 245 HS / IXY 430F") },
+        { 0x3400000, N_("PowerShot SX280 HS") },
+        { 0x3410000, N_("PowerShot SX270 HS") },
+        { 0x3420000, N_("PowerShot A3500 IS") },
+        { 0x3430000, N_("PowerShot A2600") },
+        { 0x3450000, N_("PowerShot A1400") },
+        { 0x3460000, N_("PowerShot ELPH 130 IS / IXUS 140 / IXY 110F") },
+        { 0x3470000, N_("PowerShot ELPH 115 IS / IXUS 132/135 / IXY 90F") },
+        { 0x3490000, N_("PowerShot ELPH 330 HS / IXUS 255 HS / IXY 610F") },
+        { 0x3510000, N_("PowerShot A2500") },
+        { 0x3540000, N_("PowerShot G16") },
+        { 0x3550000, N_("PowerShot S120") },
+        { 0x3560000, N_("PowerShot SX170 IS") },
+        { 0x3580000, N_("PowerShot SX510 HS") },
         { 0x4040000, N_("PowerShot G1") },
         { 0x6040000, N_("PowerShot S100 / Digital IXUS / IXY Digital") },
+        { 0x4007d673, N_("DC19/DC21/DC22") },
+        { 0x4007d674, N_("XH A1") },
         { 0x4007d675, N_("HV10") },
-        { 0x4007d777, N_("iVIS DC50") },
-        { 0x4007d778, N_("iVIS HV20") },
+        { 0x4007d676, N_("MD130/MD140/MD150/MD160/ZR850") },
+        { 0x4007d777, N_("DC50") },
+        { 0x4007d778, N_("HV20") },
+        { 0x4007d779, N_("DC211") },
+        { 0x4007d77a, N_("HG10") },
+        { 0x4007d77b, N_("HR10") },
+        { 0x4007d77c, N_("MD255/ZR950") },
+        { 0x4007d81c, N_("HF11") },
+        { 0x4007d878, N_("HV30") },
+        { 0x4007d87c, N_("XH A1S") },
+        { 0x4007d87e, N_("DC301/DC310/DC311/DC320/DC330") },
+        { 0x4007d87f, N_("FS100") },
+        { 0x4007d880, N_("HF10") },
+        { 0x4007d882, N_("HG20/HG21") },
+        { 0x4007d925, N_("HF21") },
+        { 0x4007d926, N_("HF S11") },
+        { 0x4007d978, N_("HV40") },
+        { 0x4007d987, N_("DC410/DC411/DC420") },
+        { 0x4007d988, N_("FS19/FS20/FS21/FS22/FS200") },
+        { 0x4007d989, N_("HF20/HF200") },
+        { 0x4007d98a, N_("HF S10/S100") },
+        { 0x4007da8e, N_("HF R10/R16/R17/R18/R100/R106") },
+        { 0x4007da8f, N_("HF M30/M31/M36/M300/M306") },
+        { 0x4007da90, N_("HF S20/S21/S200") },
+        { 0x4007da92, N_("FS31/FS36/FS37/FS300/FS305/FS306/FS307") },
+        { 0x4007dda9, N_("HF G25") },
         { 0x80000001, N_("EOS-1D") },
         { 0x80000167, N_("EOS-1DS") },
         { 0x80000168, N_("EOS 10D") },
@@ -161,18 +288,41 @@ namespace Exiv2 {
         { 0x80000170, N_("EOS Digital Rebel / 300D / Kiss Digital") },
         { 0x80000174, N_("EOS-1D Mark II") },
         { 0x80000175, N_("EOS 20D") },
+        { 0x80000176, N_("EOS Digital Rebel XSi / 450D / Kiss X2") },
         { 0x80000188, N_("EOS-1Ds Mark II") },
         { 0x80000189, N_("EOS Digital Rebel XT / 350D / Kiss Digital N") },
+        { 0x80000190, N_("EOS 40D") },
         { 0x80000213, N_("EOS 5D") },
+        { 0x80000215, N_("EOS-1Ds Mark III") },
+        { 0x80000218, N_("EOS 5D Mark II") },
+        { 0x80000219, N_("WFT-E1") },
         { 0x80000232, N_("EOS-1D Mark II N") },
         { 0x80000234, N_("EOS 30D") },
         { 0x80000236, N_("EOS Digital Rebel XTi / 400D / Kiss Digital X") },
+        { 0x80000241, N_("WFT-E2") },
+        { 0x80000246, N_("WFT-E3") },
         { 0x80000250, N_("EOS 7D") },
         { 0x80000252, N_("EOS Rebel T1i / 500D / Kiss X3") },
         { 0x80000254, N_("EOS Rebel XS / 1000D / Kiss F") },
         { 0x80000261, N_("EOS 50D") },
+        { 0x80000269, N_("EOS-1D X") },
         { 0x80000270, N_("EOS Rebel T2i / 550D / Kiss X4") },
+        { 0x80000271, N_("WFT-E4") },
+        { 0x80000273, N_("WFT-E5") },
         { 0x80000281, N_("EOS-1D Mark IV") },
+        { 0x80000285, N_("EOS 5D Mark III") },
+        { 0x80000286, N_("EOS Rebel T3i / 600D / Kiss X5") },
+        { 0x80000287, N_("EOS 60D") },
+        { 0x80000288, N_("EOS Rebel T3 / 1100D / Kiss X50") },
+        { 0x80000297, N_("WFT-E2 II") },
+        { 0x80000298, N_("WFT-E4 II") },
+        { 0x80000301, N_("EOS Rebel T4i / 650D / Kiss X6i") },
+        { 0x80000302, N_("EOS 6D") },
+        { 0x80000324, N_("EOS-1D C") },
+        { 0x80000325, N_("EOS 70D") },
+        { 0x80000326, N_("EOS Rebel T5i / 700D / Kiss X7i") },
+        { 0x80000331, N_("EOS M") },
+        { 0x80000346, N_("EOS Rebel SL1 / 100D / Kiss X7") },
     };
 
     //! SerialNumberFormat, tag 0x0015
@@ -217,7 +367,7 @@ namespace Exiv2 {
         TagInfo(0x0026, "AFInfo", N_("AF Info"), N_("AF info"), canonId, makerTags, unsignedShort, -1, printValue),
         TagInfo(0x0083, "OriginalDecisionDataOffset", N_("Original Decision Data Offset"), N_("Original decision data offset"), canonId, makerTags, signedLong, -1, printValue),
         TagInfo(0x00a4, "WhiteBalanceTable", N_("White Balance Table"), N_("White balance table"), canonId, makerTags, unsignedShort, -1, printValue),
-        TagInfo(0x0095, "LensModel", N_("LensModel"), N_("LensModel"), canonId, makerTags, asciiString, -1, printValue),
+        TagInfo(0x0095, "LensModel", N_("Lens Model"), N_("Lens model"), canonId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0096, "InternalSerialNumber", N_("Internal Serial Number"), N_("Internal serial number"), canonId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0097, "DustRemovalData", N_("Dust Removal Data"), N_("Dust removal data"), canonId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0099, "CustomFunctions", N_("Custom Functions"), N_("Custom functions"), canonId, makerTags, unsignedShort, -1, printValue),
@@ -421,24 +571,25 @@ namespace Exiv2 {
         {   1, "Canon EF 50mm f/1.8"                                        },
         {   2, "Canon EF 28mm f/2.8"                                        },
         {   3, "Canon EF 135mm f/2.8 Soft"                                  },
-        {   4, "Canon EF 35-105mm f/3.5-4.5 or Sigma Lens"                  }, // 0
+        {   4, "Canon EF 35-105mm f/3.5-4.5"                                }, // 0
         {   4, "Sigma UC Zoom 35-135mm f/4-5.6"                             }, // 1
         {   5, "Canon EF 35-70mm f/3.5-4.5"                                 },
-        {   6, "Canon EF 28-70mm f/3.5-4.5 or Sigma or Tokina Lens"         }, // 0
+        {   6, "Canon EF 28-70mm f/3.5-4.5"                                 }, // 0
         {   6, "Sigma 18-50mm f/3.5-5.6 DC"                                 }, // 1
         {   6, "Sigma 18-125mm f/3.5-5.6 DC IF ASP"                         }, // 2
         {   6, "Tokina AF193-2 19-35mm f/3.5-4.5"                           }, // 3
         {   6, "Sigma 28-80mm f/3.5-5.6 II Macro"                           }, // 4
         {   7, "Canon EF 100-300mm f/5.6L"                                  },
         {   8, "Canon EF 100-300mm f/5.6"                                   }, // 0
-        {   8, "Sigma 70-300mm f/4-5.6 DG Macro"                            }, // 1
-        {   8, "Tokina AT-X242AF 24-200mm f/3.5-5.6"                        }, // 2
+        {   8, "Sigma 70-300mm f/4-5.6 [APO] DG Macro"                      }, // 1
+        {   8, "Tokina AT-X 242 AF 24-200mm f/3.5-5.6"                      }, // 2
         {   9, "Canon EF 70-210mm f/4"                                      }, // 0
         {   9, "Sigma 55-200mm f/4-5.6 DC"                                  }, // 1
         {  10, "Canon EF 50mm f/2.5 Macro"                                  }, // 0
         {  10, "Sigma 50mm f/2.8 EX"                                        }, // 1
         {  10, "Sigma 28mm f/1.8"                                           }, // 2
         {  10, "Sigma 105mm f/2.8 Macro EX"                                 }, // 3
+        {  10, "Sigma 70mm f/2.8 EX DG Macro EF"                            }, // 4
         {  11, "Canon EF 35mm f/2"                                          },
         {  13, "Canon EF 15mm f/2.8 Fisheye"                                },
         {  14, "Canon EF 50-200mm f/3.5-4.5L"                               },
@@ -449,11 +600,11 @@ namespace Exiv2 {
         {  20, "Canon EF 100-200mm f/4.5A"                                  },
         {  21, "Canon EF 80-200mm f/2.8L"                                   },
         {  22, "Canon EF 20-35mm f/2.8L"                                    }, // 0
-        {  22, "Tokina AT-X280AF PRO 28-80mm f/2.8 Aspherical"              }, // 1
+        {  22, "Tokina AT-X 280 AF PRO 28-80mm f/2.8 Aspherical"            }, // 1
         {  23, "Canon EF 35-105mm f/3.5-4.5"                                },
         {  24, "Canon EF 35-80mm f/4-5.6 Power Zoom"                        },
         {  25, "Canon EF 35-80mm f/4-5.6 Power Zoom"                        },
-        {  26, "Canon EF 100mm f/2.8 Macro or Cosina or Tamron Lens"        }, // 0
+        {  26, "Canon EF 100mm f/2.8 Macro"                                 }, // 0
         {  26, "Cosina 100mm f/3.5 Macro AF"                                }, // 1
         {  26, "Tamron SP AF 90mm f/2.8 Di Macro"                           }, // 2
         {  26, "Tamron SP AF 180mm f/3.5 Di Macro"                          }, // 3
@@ -470,9 +621,14 @@ namespace Exiv2 {
         {  31, "Tamron SP AF 300mm f/2.8 LD IF"                             }, // 1
         {  32, "Canon EF 24mm f/2.8"                                        }, // 0
         {  32, "Sigma 15mm f/2.8 EX Fisheye"                                }, // 1
-        {  33, "Voigtlander or Zeiss Lens"                                  }, // 0
+        {  33, "Voigtlander or Carl Zeiss Lens"                             }, // 0
         {  33, "Voigtlander Ultron 40mm f/2 SLII Aspherical"                }, // 1
-        {  33, "Zeiss Distagon 35mm T* f/2 ZE"                              }, // 2
+        {  33, "Carl Zeiss Distagon 15mm T* f/2.8 ZE"                       }, // 2
+        {  33, "Carl Zeiss Distagon 18mm T* f/3.5 ZE"                       }, // 3
+        {  33, "Carl Zeiss Distagon 21mm T* f/2.8 ZE"                       }, // 4
+        {  33, "Carl Zeiss Distagon 28mm T* f/2 ZE"                         }, // 5
+        {  33, "Carl Zeiss Distagon 35mm T* f/2 ZE"                         }, // 6
+        {  33, "Carl Zeiss Planar 50mm T* f/1.4 ZE"                         }, // 7
         {  35, "Canon EF 35-80mm f/4-5.6"                                   },
         {  36, "Canon EF 38-76mm f/4.5-5.6"                                 },
         {  37, "Canon EF 35-80mm f/4-5.6"                                   }, // 0
@@ -494,6 +650,9 @@ namespace Exiv2 {
         {  49, "Canon EF-S 55-250mm f/4-5.6 IS"                             },
         {  50, "Canon EF-S 18-200mm f/3.5-5.6 IS"                           },
         {  51, "Canon EF-S 18-135mm f/3.5-5.6 IS"                           },
+        {  52, "Canon EF-S 18-55mm f/3.5-5.6 IS II"                         },
+        {  53, "Canon EF-S 18-55mm f/3.5-5.6 III"                           },
+        {  54, "Canon EF-S 55-250mm f/4-5.6 IS II"                          },
         {  94, "Canon TS-E 17mm f/4L"                                       },
         {  95, "Canon TS-E 24.0mm f/3.5 L II"                               },
         { 124, "Canon MP-E 65mm f/2.8 1-5x Macro Photo"                     },
@@ -508,6 +667,8 @@ namespace Exiv2 {
         { 131, "Sigma 17-70mm f/2.8-4.5 DC Macro"                           }, // 3
         { 131, "Sigma APO 50-150mm f/2.8 EX DC HSM"                         }, // 4
         { 131, "Sigma APO 120-300mm f/2.8 EX DG HSM"                        }, // 5
+        { 131, "Sigma 4.5mm F2.8 EX DC HSM Circular Fisheye"                }, // 6
+        { 131, "Sigma 70-200mm f/2.8 APO EX HSM"                            }, // 7
         { 132, "Canon EF 1200mm f/5.6L"                                     },
         { 134, "Canon EF 600mm f/4L IS"                                     },
         { 135, "Canon EF 200mm f/1.8L"                                      },
@@ -520,6 +681,15 @@ namespace Exiv2 {
         { 137, "Sigma 18-125mm f/3.8-5.6 DC OS HSM"                         }, // 5
         { 137, "Sigma 17-70mm f/2.8-4 DC Macro OS HSM"                      }, // 6
         { 137, "Sigma 17-50mm f/2.8 OS HSM"                                 }, // 7
+        { 137, "Sigma 18-200mm f/3.5-6.3 II DC OS HSM"                      }, // 8
+        { 137, "Tamron AF 18-270mm f/3.5-6.3 Di II VC PZD"                  }, // 9
+        { 137, "Sigma 8-16mm f/4.5-5.6 DC HSM"                              }, // 10
+        { 137, "Tamron SP 17-50mm f/2.8 XR Di II VC"                        }, // 11
+        { 137, "Tamron SP 60mm f/2 Macro Di II"                             }, // 12
+        { 137, "Sigma 10-20mm f/3.5 EX DC HSM"                              }, // 13
+        { 137, "Tamron SP 24-70mm f/2.8 Di VC USD"                          }, // 14
+        { 137, "Sigma 18-35mm f/1.8 DC HSM"                                 }, // 15
+        { 137, "Sigma 12-24mm f/4.5-5.6 DG HSM II"                          }, // 16
         { 138, "Canon EF 28-80mm f/2.8-4L"                                  },
         { 139, "Canon EF 400mm f/2.8L"                                      },
         { 140, "Canon EF 500mm f/4.5L"                                      },
@@ -550,15 +720,18 @@ namespace Exiv2 {
         { 154, "Canon EF 20mm f/2.8 USM"                                    },
         { 155, "Canon EF 85mm f/1.8 USM"                                    },
         { 156, "Canon EF 28-105mm f/3.5-4.5 USM"                            }, // 0
-        { 156, "Tamron SP AF 70-300mm F4-5.6 Di VC USD"                     }, // 1
+        { 156, "Tamron SP AF 70-300mm f/4-5.6 Di VC USD"                    }, // 1
         { 160, "Canon EF 20-35mm f/3.5-4.5 USM"                             }, // 0
         { 160, "Tamron AF 19-35mm f/3.5-4.5"                                }, // 1
-        { 160, "Tokina AT-X 107 AF DX Fish-eye 10-17mm f/3.5-4.5"           }, // 2
+        { 160, "Tokina AT-X 124 AF 12-24mm f/4 DX"                          }, // 2
+        { 160, "Tokina AT-X 107 AF DX Fish-eye 10-17mm f/3.5-4.5"           }, // 3
+        { 160, "Tokina AT-X 116 PRO DX AF 11-16mm f/2.8"                    }, // 4
         { 161, "Canon EF 28-70mm f/2.8L"                                    }, // 0
         { 161, "Sigma 24-70mm EX f/2.8"                                     }, // 1
         { 161, "Sigma 28-70mm f/2.8 EX"                                     }, // 2
         { 161, "Tamron AF 17-50mm f/2.8 Di-II LD Aspherical"                }, // 3
         { 161, "Tamron 90mm f/2.8"                                          }, // 4
+        { 161, "Sigma 24-60mm f/2.8 EX DG"                                  }, // 5
         { 162, "Canon EF 200mm f/2.8L"                                      },
         { 163, "Canon EF 300mm f/4L"                                        },
         { 164, "Canon EF 400mm f/5.6L"                                      },
@@ -571,14 +744,19 @@ namespace Exiv2 {
         { 169, "Sigma 15-30mm f/3.5-4.5 EX DG Aspherical"                   }, // 2
         { 169, "Sigma 18-50mm f/2.8 Macro"                                  }, // 3
         { 169, "Sigma 50mm f/1.4 EX DG HSM"                                 }, // 4
+        { 169, "Sigma 85mm f/1.4 EX DG HSM"                                 }, // 5
+        { 169, "Sigma 30mm f/1.4 EX DC HSM"                                 }, // 6
+        { 169, "Sigma 35mm f/1.4 DG HSM"                                    }, // 7
         { 170, "Canon EF 200mm f/2.8L II"                                   },
         { 171, "Canon EF 300mm f/4L"                                        },
         { 172, "Canon EF 400mm f/5.6L"                                      },
-        { 173, "Canon EF 180mm Macro f/3.5L or Sigma Lens"                  }, // 0
+        { 173, "Canon EF 180mm Macro f/3.5L"                                }, // 0
         { 173, "Sigma 180mm EX HSM Macro f/3.5"                             }, // 1
         { 173, "Sigma APO Macro 150mm f/3.5 EX DG IF HSM"                   }, // 2
         { 174, "Canon EF 135mm f/2L"                                        }, // 0
         { 174, "Sigma 70-200mm f/2.8 EX DG APO OS HSM"                      }, // 1
+        { 174, "Sigma 50-500mm f/4.5-6.3 APO DG OS HSM"                     }, // 2
+        { 174, "Sigma 150-500mm f/5-6.3 APO DG OS HSM"                      }, // 3
         { 175, "Canon EF 400mm f/2.8L"                                      },
         { 176, "Canon EF 24-85mm f/3.5-4.5 USM"                             },
         { 177, "Canon EF 300mm f/4L IS"                                     },
@@ -587,7 +765,9 @@ namespace Exiv2 {
         { 180, "Canon EF 35mm f/1.4L"                                       },
         { 181, "Canon EF 100-400mm f/4.5-5.6L IS + 1.4x"                    },
         { 182, "Canon EF 100-400mm f/4.5-5.6L IS + 2x"                      },
-        { 183, "Canon EF 100-400mm f/4.5-5.6L IS"                           },
+        { 183, "Canon EF 100-400mm f/4.5-5.6L IS"                           }, // 0
+        { 183, "Sigma 150mm f/2.8 EX DG OS HSM APO Macro"                   }, // 1
+        { 183, "Sigma 105mm f/2.8 EX DG OS HSM Macro"                       }, // 2
         { 184, "Canon EF 400mm f/2.8L + 2x"                                 },
         { 185, "Canon EF 600mm f/4L IS"                                     },
         { 186, "Canon EF 70-200mm f/4L"                                     },
@@ -601,7 +781,8 @@ namespace Exiv2 {
         { 195, "Canon EF 35-105mm f/4.5-5.6 USM"                            },
         { 196, "Canon EF 75-300mm f/4-5.6 USM"                              },
         { 197, "Canon EF 75-300mm f/4-5.6 IS USM"                           },
-        { 198, "Canon EF 50mm f/1.4 USM"                                    },
+        { 198, "Canon EF 50mm f/1.4 USM"                                    }, // 0
+        { 198, "Zeiss Otus 55mm f/1.4 ZE"                                   }, // 1
         { 199, "Canon EF 28-80mm f/3.5-5.6 USM"                             },
         { 200, "Canon EF 75-300mm f/4-5.6 USM"                              },
         { 201, "Canon EF 28-80mm f/3.5-5.6 USM"                             },
@@ -642,8 +823,28 @@ namespace Exiv2 {
         { 249, "Canon EF 800mm f/5.6L IS"                                   },
         { 250, "Canon EF 24 f/1.4L II"                                      },
         { 251, "Canon EF 70-200mm f/2.8L IS II USM"                         },
+        { 252, "Canon EF 70-200mm f/2.8L IS II USM + 1.4x"                  },
+        { 253, "Canon EF 70-200mm f/2.8L IS II USM + 2x"                    },
         { 254, "Canon EF 100mm f/2.8L Macro IS USM"                         },
-        { 488, "Canon EF-S 15-85mm f/3.5-5.6 IS USM"                        }
+        { 488, "Canon EF-S 15-85mm f/3.5-5.6 IS USM"                        },
+        { 489, "Canon EF 70-300mm f/4-5.6L IS USM"                          },
+        { 490, "Canon EF 8-15mm f/4L USM"                                   },
+        { 491, "Canon EF 300mm f/2.8L IS II USM"                            },
+        { 492, "Canon EF 400mm f/2.8L IS II USM"                            },
+        { 493, "Canon EF 24-105mm f/4L IS USM"                              },
+        { 494, "Canon EF 600mm f/4.0L IS II USM"                            },
+        { 495, "Canon EF 24-70mm f/2.8L II USM"                             },
+        { 496, "Canon EF 200-400mm f/4L IS USM"                             },
+        { 502, "Canon EF 28mm f/2.8 IS USM"                                 },
+        { 503, "Canon EF 24mm f/2.8 IS USM"                                 },
+        { 504, "Canon EF 24-70mm f/4L IS USM"                               },
+        { 505, "Canon EF 35mm f/2 IS USM"                                   },
+        { 4142,"Canon EF-S 18-135mm f/3.5-5.6 IS STM"                       },
+        { 4143,"Canon EF-M 18-55mm f/3.5-5.6 IS STM"                        },
+        { 4144,"Canon EF 40mm f/2.8 STM"                                    },
+        { 4145,"Canon EF-M 22mm f/2 STM"                                    },
+        { 4146,"Canon EF-S 18-55mm f/3.5-5.6 IS STM"                        },
+        { 4147,"Canon EF-M 11-22mm f/4-5.6 IS STM"                          }
     };
 
     //! A lens id and a pretty-print function for special treatment of the id.
@@ -656,30 +857,31 @@ namespace Exiv2 {
 
     //! List of lens ids which require special treatment with the medicine
     const LensIdFct lensIdFct[] = {
-        {   4, 0                        }, // no known medicine
-        {   6, printCsLensByFocalLength },
-        {   8, printCsLensByFocalLength },
-        {   9, printCsLensByFocalLength },
-        {  10, printCsLensByFocalLength }, // works partly
-        {  22, printCsLensByFocalLength },
-        {  26, printCsLensByFocalLength }, // works partly
-        {  28, printCsLensByFocalLength },
-        {  31, printCsLensByFocalLength },
-        {  32, printCsLensByFocalLength },
-        {  33, printCsLensByFocalLength }, // not tested
-        {  37, printCsLensByFocalLength },
-        {  42, printCsLensByFocalLength },
-        { 131, printCsLensByFocalLength },
-        { 137, printCsLensByFocalLength }, // not tested
-        { 150, printCsLensByFocalLength },
-        { 152, printCsLensByFocalLength },
-        { 153, printCsLensByFocalLength },
-        { 156, printCsLensByFocalLength },
-        { 160, printCsLensByFocalLength },
-        { 161, printCsLensByFocalLength },
-        { 169, printCsLensByFocalLength },
-        { 173, printCsLensByFocalLength }, // works partly
-        { 174, printCsLensByFocalLength }  // not tested
+        {   4, printCsLensByFocalLengthAndMaxAperture }, // not tested
+        {   6, printCsLensByFocalLengthAndMaxAperture },
+        {   8, printCsLensByFocalLengthAndMaxAperture },
+        {   9, printCsLensByFocalLengthAndMaxAperture },
+        {  10, printCsLensByFocalLengthAndMaxAperture }, // works partly
+        {  22, printCsLensByFocalLengthAndMaxAperture },
+        {  26, printCsLensByFocalLengthAndMaxAperture }, // works partly
+        {  28, printCsLensByFocalLengthAndMaxAperture },
+        {  31, printCsLensByFocalLengthAndMaxAperture },
+        {  32, printCsLensByFocalLengthAndMaxAperture },
+        {  33, printCsLensByFocalLengthAndMaxAperture }, // not tested
+        {  37, printCsLensByFocalLengthAndMaxAperture },
+        {  42, printCsLensByFocalLengthAndMaxAperture },
+        { 131, printCsLensByFocalLengthAndMaxAperture },
+        { 137, printCsLensByFocalLengthAndMaxAperture }, // not tested
+        { 150, printCsLensByFocalLengthAndMaxAperture },
+        { 152, printCsLensByFocalLengthAndMaxAperture },
+        { 153, printCsLensByFocalLengthAndMaxAperture },
+        { 156, printCsLensByFocalLengthAndMaxAperture },
+        { 160, printCsLensByFocalLengthAndMaxAperture },
+        { 161, printCsLensByFocalLengthAndMaxAperture },
+        { 169, printCsLensByFocalLengthAndMaxAperture },
+        { 173, printCsLensByFocalLengthAndMaxAperture }, // works partly
+        { 174, printCsLensByFocalLengthAndMaxAperture }, // not tested
+        { 183, printCsLensByFocalLengthAndMaxAperture }  // not tested
     };
 
     //! FlashActivity, tag 0x001c
@@ -1245,25 +1447,27 @@ namespace Exiv2 {
     }
 
     //! Helper structure
-    struct LensTypeAndFocalLength {
+    struct LensTypeAndFocalLengthAndMaxAperture {
         long        lensType_;                  //!< Lens type
         std::string focalLength_;               //!< Focal length
+        std::string maxAperture_;               //!< Aperture
     };
 
     //! Compare tag details with a lens entry
-    bool operator==(const TagDetails& td, const LensTypeAndFocalLength& ltfl) {
+    bool operator==(const TagDetails& td, const LensTypeAndFocalLengthAndMaxAperture& ltfl) {
         return (   td.val_ == ltfl.lensType_
-                && std::string(td.label_).find(ltfl.focalLength_) != std::string::npos);
+                && std::string(td.label_).find(ltfl.focalLength_) != std::string::npos
+                && std::string(td.label_).find(ltfl.maxAperture_) != std::string::npos);
     }
 
-    std::ostream& printCsLensByFocalLength(std::ostream& os,
+    std::ostream& printCsLensByFocalLengthAndMaxAperture(std::ostream& os,
                                            const Value& value,
                                            const ExifData* metadata)
     {
         if (   !metadata || value.typeId() != unsignedShort
             || value.count() == 0) return os << value;
 
-        LensTypeAndFocalLength ltfl;
+        LensTypeAndFocalLengthAndMaxAperture ltfl;
         ltfl.lensType_ = value.toLong();
 
         ExifKey key("Exif.CanonCs.Lens");
@@ -1287,6 +1491,23 @@ namespace Exiv2 {
         }
         if (ltfl.focalLength_.empty()) return os << value;
 
+        ExifKey key2("Exif.CanonCs.MaxAperture");
+        pos = metadata->findKey(key2);
+        if (   pos != metadata->end()
+            && pos->value().count() == 1
+            && pos->value().typeId() == unsignedShort) {
+
+            long val = static_cast<int16_t>(pos->value().toLong(0));
+            if (val > 0)
+            {
+                std::ostringstream oss;
+                oss << std::setprecision(2);
+                oss << fnumber(canonEv(val));
+                ltfl.maxAperture_ = oss.str();
+            }
+        }
+        if (ltfl.maxAperture_.empty()) return os << value;
+
         const TagDetails* td = find(canonCsLensType, ltfl);
         if (!td) return os << value;
         return os << td->label_;
