@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2012 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      crwimage.cpp
-  Version:   $Rev: 2681 $
+  Version:   $Rev: 3091 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   28-Aug-05, ahu: created
 
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: crwimage.cpp 2681 2012-03-22 15:19:35Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: crwimage.cpp 3091 2013-07-24 05:15:04Z robinwmills $")
 
 // Define DEBUG to output debug information to std::cerr, e.g, by calling make
 // like this: make DEFS=-DDEBUG crwimage.o
@@ -825,7 +825,7 @@ namespace Exiv2 {
               if not found, create it
               set value
         */
-
+        AutoPtr m;
         CiffComponent* cc = 0;
         const Components::iterator b = components_.begin();
         const Components::iterator e = components_.end();
@@ -842,7 +842,7 @@ namespace Exiv2 {
             }
             if (cc == 0) {
                 // Directory doesn't exist yet, add it
-                AutoPtr m(new CiffDirectory(csd.crwDir_, csd.parent_));
+                m = AutoPtr(new CiffDirectory(csd.crwDir_, csd.parent_));
                 cc = m.get();
                 add(m);
             }
@@ -859,7 +859,7 @@ namespace Exiv2 {
             }
             if (cc == 0) {
                 // Tag doesn't exist yet, add it
-                AutoPtr m(new CiffEntry(crwTagId, tag()));
+                m = AutoPtr(new CiffEntry(crwTagId, tag()));
                 cc = m.get();
                 add(m);
             }
