@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2012 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      easyaccess.cpp
-  Version:   $Rev: 2711 $
+  Version:   $Rev: 3091 $
   Author(s): Carsten Pfeiffer <pfeiffer@kde.org>
              Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   28-Feb-09, gis: created
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: easyaccess.cpp 2711 2012-04-22 05:28:42Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: easyaccess.cpp 3091 2013-07-24 05:15:04Z robinwmills $")
 
 // *****************************************************************************
 // included header files
@@ -256,7 +256,10 @@ namespace Exiv2 {
     ExifData::const_iterator lensName(const ExifData& ed)
     {
         static const char* keys[] = {
+            // Exif.Canon.LensModel only reports focal length.
+            // Try Exif.CanonCs.LensType first. 
             "Exif.CanonCs.LensType",
+            "Exif.Photo.LensModel",
             "Exif.NikonLd1.LensIDNumber",
             "Exif.NikonLd2.LensIDNumber",
             "Exif.NikonLd3.LensIDNumber",
@@ -266,7 +269,7 @@ namespace Exiv2 {
             "Exif.SonyMinolta.LensID",
             "Exif.Sony1.LensID",
             "Exif.Sony2.LensID",
-            "Exif.OlympusEq.LensModel",
+            "Exif.OlympusEq.LensType",
             "Exif.Panasonic.LensType",
             "Exif.Samsung2.LensType"
         };
