@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -386,6 +386,7 @@ namespace {
         size_t posBeginPhotoshop = posEndEps;
         size_t posEndPhotoshop = posEndEps;
         size_t posPage = posEndEps;
+        size_t posBeginPageSetup = posEndEps;
         size_t posEndPageSetup = posEndEps;
         size_t posPageTrailer = posEndEps;
         size_t posEof = posEndEps;
@@ -393,10 +394,11 @@ namespace {
         unsigned int depth = 0;
         const unsigned int maxDepth = UINT_MAX;
         bool illustrator8 = false;
+        bool corelDraw = false;
         bool implicitPage = false;
+        bool implicitPageSetup = false;
         bool implicitPageTrailer = false;
         bool inDefaultsPreviewPrologSetup = false;
-        bool inPageSetup = false;
         bool inRemovableEmbedding = false;
         std::string removableEmbeddingEndLine;
         unsigned int removableEmbeddingsWithUnmarkedTrailer = 0;
@@ -438,6 +440,7 @@ namespace {
             if (significantLine) {
                 EXV_DEBUG << "readWriteEpsMetadata: Found significant line \"" << line << "\" at position: " << startPos << "\n";
             }
+            significantLine = true;
             #endif
             if (depth != 0) continue;
             // explicit "Begin" comments
@@ -463,7 +466,7 @@ namespace {
                 #endif
                 throw Error(write ? 21 : 14);
             } else if (line == "%%BeginPageSetup") {
-                inPageSetup = true;
+                posBeginPageSetup = startPos;
             } else if (!inRemovableEmbedding && line == "%Exiv2BeginXMP: Before %%EndPageSetup") {
                 inRemovableEmbedding = true;
                 removableEmbeddings.push_back(std::make_pair(startPos, startPos));
@@ -494,6 +497,7 @@ namespace {
             if (significantLine) {
                 EXV_DEBUG << "readWriteEpsMetadata: Found significant line \"" << line << "\" at position: " << startPos << "\n";
             }
+            significantLine = true;
             #endif
             // implicit comments
             if (line == "%%EOF" || line == "%begin_xml_code" || !(line.size() >= 2 && line[0] == '%' && '\x21' <= line[1] && line[1] <= '\x7e')) {
@@ -507,18 +511,40 @@ namespace {
             if (posPage == posEndEps && posEndComments != posEndEps && !inDefaultsPreviewPrologSetup && !inRemovableEmbedding && !onlyWhitespaces(line)) {
                 posPage = startPos;
                 implicitPage = true;
-                posEndPageSetup = startPos;
                 #ifdef DEBUG
-                EXV_DEBUG << "readWriteEpsMetadata: Found implicit Page and EndPageSetup at position: " << startPos << "\n";
+                EXV_DEBUG << "readWriteEpsMetadata: Found implicit Page at position: " << startPos << "\n";
                 #endif
             }
-            if (posEndPageSetup == posEndEps && posPage != posEndEps && !inPageSetup && !inRemovableEmbedding && line.size() >= 1 && line[0] != '%') {
+            if (posBeginPageSetup == posEndEps && (implicitPage || (posPage != posEndEps && !inRemovableEmbedding && line.size() >= 1 && line[0] != '%'))) {
+                posBeginPageSetup = startPos;
+                implicitPageSetup = true;
+                #ifdef DEBUG
+                EXV_DEBUG << "readWriteEpsMetadata: Found implicit BeginPageSetup at position: " << startPos << "\n";
+                #endif
+            }
+            if (posEndPageSetup == posEndEps && implicitPageSetup && !inRemovableEmbedding && line.size() >= 1 && line[0] != '%') {
                 posEndPageSetup = startPos;
                 #ifdef DEBUG
                 EXV_DEBUG << "readWriteEpsMetadata: Found implicit EndPageSetup at position: " << startPos << "\n";
                 #endif
             }
             if (line.size() >= 1 && line[0] != '%') continue; // performance optimization
+            if (line == "%%EOF" || line == "%%Trailer" || line == "%%PageTrailer") {
+                if (posBeginPageSetup == posEndEps) {
+                    posBeginPageSetup = startPos;
+                    implicitPageSetup = true;
+                    #ifdef DEBUG
+                    EXV_DEBUG << "readWriteEpsMetadata: Found implicit BeginPageSetup at position: " << startPos << "\n";
+                    #endif
+                }
+                if (posEndPageSetup == posEndEps) {
+                    posEndPageSetup = startPos;
+                    implicitPageSetup = true;
+                    #ifdef DEBUG
+                    EXV_DEBUG << "readWriteEpsMetadata: Found implicit EndPageSetup at position: " << startPos << "\n";
+                    #endif
+                }
+            }
             if (line == "%%EOF" || line == "%%Trailer") {
                 if (posPageTrailer == posEndEps) {
                     posPageTrailer = startPos;
@@ -547,6 +573,8 @@ namespace {
                 posAi7ThumbnailEndData = startPos;
             } else if (posEndComments == posEndEps && line == "%%EndComments") {
                 posEndComments = startPos;
+            } else if (inDefaultsPreviewPrologSetup && startsWith(line, "%%BeginResource: procset wCorel")) {
+                corelDraw = true;
             } else if (line == "%%EndPreview") {
                 inDefaultsPreviewPrologSetup = false;
             } else if (line == "%%EndDefaults") {
@@ -556,7 +584,6 @@ namespace {
             } else if (line == "%%EndSetup") {
                 inDefaultsPreviewPrologSetup = false;
             } else if (posEndPageSetup == posEndEps && line == "%%EndPageSetup") {
-                inPageSetup = false;
                 posEndPageSetup = startPos;
             } else if (posPageTrailer == posEndEps && line == "%%PageTrailer") {
                 posPageTrailer = startPos;
@@ -810,6 +837,7 @@ namespace {
             positions.push_back(posExiv2Website);
             positions.push_back(posEndComments);
             positions.push_back(posPage);
+            positions.push_back(posBeginPageSetup);
             positions.push_back(posEndPageSetup);
             positions.push_back(posPageTrailer);
             positions.push_back(posEof);
@@ -834,6 +862,9 @@ namespace {
             for (std::vector<size_t>::const_iterator i = positions.begin(); i != positions.end(); i++) {
                 const size_t pos = *i;
                 if (pos == prevPos) continue;
+                #ifdef DEBUG
+                EXV_DEBUG << "readWriteEpsMetadata: Writing at " << pos << "\n";
+                #endif
                 if (pos < prevSkipPos) {
                     #ifndef SUPPRESS_WARNINGS
                     EXV_WARNING << "Internal error while assembling the result EPS document: "
@@ -856,21 +887,33 @@ namespace {
                     if (line == "%%LanguageLevel:1" || line == "%%LanguageLevel: 1") {
                         writeTemp(*tempIo, "%%LanguageLevel: 2" + lineEnding);
                         skipPos = posLineEnd;
+                        #ifdef DEBUG
+                        EXV_DEBUG << "readWriteEpsMetadata: Skipping to " << skipPos << " at " << __FILE__ << ":" << __LINE__ << "\n";
+                        #endif
                     }
                 }
                 if (pos == posContainsXmp && posContainsXmp != posEndEps) {
                     if (line != containsXmpLine) {
                         writeTemp(*tempIo, containsXmpLine + lineEnding);
                         skipPos = posLineEnd;
+                        #ifdef DEBUG
+                        EXV_DEBUG << "readWriteEpsMetadata: Skipping to " << skipPos << " at " << __FILE__ << ":" << __LINE__ << "\n";
+                        #endif
                     }
                 }
                 if (pos == posExiv2Version && posExiv2Version != posEndEps) {
                     writeTemp(*tempIo, "%Exiv2Version: " + versionNumberHexString() + lineEnding);
                     skipPos = posLineEnd;
+                    #ifdef DEBUG
+                    EXV_DEBUG << "readWriteEpsMetadata: Skipping to " << skipPos << " at " << __FILE__ << ":" << __LINE__ << "\n";
+                    #endif
                 }
                 if (pos == posExiv2Website && posExiv2Website != posEndEps) {
                     writeTemp(*tempIo, "%Exiv2Website: http://www.exiv2.org/" + lineEnding);
                     skipPos = posLineEnd;
+                    #ifdef DEBUG
+                    EXV_DEBUG << "readWriteEpsMetadata: Skipping to " << skipPos << " at " << __FILE__ << ":" << __LINE__ << "\n";
+                    #endif
                 }
                 if (pos == posEndComments) {
                     if (posLanguageLevel == posEndEps && !deleteXmp && !useFlexibleEmbedding) {
@@ -899,6 +942,11 @@ namespace {
                         writeTemp(*tempIo, "%%EndPageComments" + lineEnding);
                     }
                 }
+                if (pos == posBeginPageSetup) {
+                    if (line != "%%BeginPageSetup") {
+                        writeTemp(*tempIo, "%%BeginPageSetup" + lineEnding);
+                    }
+                }
                 if (useFlexibleEmbedding) {
                     // insert XMP metadata into existing flexible embedding
                     if (pos == xmpPos) {
@@ -907,21 +955,29 @@ namespace {
                         }
                         writeTemp(*tempIo, xmpPacket);
                         skipPos += xmpSize;
+                        #ifdef DEBUG
+                        EXV_DEBUG << "readWriteEpsMetadata: Skipping to " << skipPos << " at " << __FILE__ << ":" << __LINE__ << "\n";
+                        #endif
                     }
-                } else {
+                }
+                if (!useFlexibleEmbedding) {
                     // remove preceding embedding(s)
                     for (std::vector<std::pair<size_t, size_t> >::const_iterator e = removableEmbeddings.begin(); e != removableEmbeddings.end(); e++) {
                         if (pos == e->first) {
                             skipPos = e->second;
+                            #ifdef DEBUG
+                            EXV_DEBUG << "readWriteEpsMetadata: Skipping to " << skipPos << " at " << __FILE__ << ":" << __LINE__ << "\n";
+                            #endif
                             break;
                         }
                     }
                     // insert XMP metadata with new flexible embedding, if necessary
                     if (pos == posEndPageSetup && !deleteXmp) {
-                        if (line != "%%EndPageSetup") {
-                            writeTemp(*tempIo, "%%BeginPageSetup" + lineEnding);
-                        }
                         writeTemp(*tempIo, "%Exiv2BeginXMP: Before %%EndPageSetup" + lineEnding);
+                        if (corelDraw) {
+                            writeTemp(*tempIo, "%Exiv2Notice: The following line is needed by CorelDRAW." + lineEnding);
+                            writeTemp(*tempIo, "@rs" + lineEnding);
+                        }
                         if (posBeginPhotoshop != posEndEps) {
                             writeTemp(*tempIo, "%Exiv2Notice: The following line is needed by Photoshop." + lineEnding);
                             writeTemp(*tempIo, "%begin_xml_code" + lineEnding);
@@ -953,14 +1009,25 @@ namespace {
                             writeTemp(*tempIo, "%Exiv2Notice: The following line is needed by Photoshop." + lineEnding);
                             writeTemp(*tempIo, "%end_xml_code" + lineEnding);
                         }
-                        writeTemp(*tempIo, "%Exiv2EndXMP" + lineEnding);
-                        if (line != "%%EndPageSetup") {
-                            writeTemp(*tempIo, "%%EndPageSetup" + lineEnding);
+                        if (corelDraw) {
+                            writeTemp(*tempIo, "%Exiv2Notice: The following line is needed by CorelDRAW." + lineEnding);
+                            writeTemp(*tempIo, "@sv" + lineEnding);
                         }
+                        writeTemp(*tempIo, "%Exiv2EndXMP" + lineEnding);
                     }
+                }
+                if (pos == posEndPageSetup) {
+                    if (line != "%%EndPageSetup") {
+                        writeTemp(*tempIo, "%%EndPageSetup" + lineEnding);
+                    }
+                }
+                if (!useFlexibleEmbedding) {
                     if (pos == posPageTrailer && !deleteXmp) {
                         if (!implicitPageTrailer) {
                             skipPos = posLineEnd;
+                            #ifdef DEBUG
+                            EXV_DEBUG << "readWriteEpsMetadata: Skipping to " << skipPos << " at " << __FILE__ << ":" << __LINE__ << "\n";
+                            #endif
                         }
                         writeTemp(*tempIo, "%%PageTrailer" + lineEnding);
                         writeTemp(*tempIo, "%Exiv2BeginXMP: After %%PageTrailer" + lineEnding);
