@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2010 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,13 +20,13 @@
  */
 /*
   File:      error.cpp
-  Version:   $Rev: 2353 $
+  Version:   $Rev: 3091 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   02-Apr-05, ahu: created
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: error.cpp 2353 2010-09-21 15:45:07Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: error.cpp 3091 2013-07-24 05:15:04Z robinwmills $")
 
 // *****************************************************************************
 // included header files
@@ -104,7 +104,8 @@ namespace {
         { 48, N_("Invalid XmpText type `%1'") }, // %1=type
         { 49, N_("TIFF directory %1 has too many entries") }, // %1=TIFF directory name
         { 50, N_("Multiple TIFF array element tags %1 in one directory") }, // %1=tag number
-        { 51, N_("TIFF array element tag %1 has wrong type") } // %1=tag number
+        { 51, N_("TIFF array element tag %1 has wrong type") }, // %1=tag number
+        { 52, N_("%1 has invalid XMP value type `%2'") } // %1=key, %2=value type
     };
 
 }
@@ -113,14 +114,14 @@ namespace {
 // class member definitions
 namespace Exiv2 {
 
-    LogMsg::Level LogMsg::level_ = LogMsg::info; // Default output level
+    LogMsg::Level LogMsg::level_ = LogMsg::warn; // Default output level
     LogMsg::Handler LogMsg::handler_ = LogMsg::defaultHandler;
 
     void LogMsg::defaultHandler(int level, const char* s)
     {
         switch (static_cast<LogMsg::Level>(level)) {
         case LogMsg::debug: std::cerr << "Debug: "; break;
-        case LogMsg::info:  break;
+        case LogMsg::info:  std::cerr << "Info: "; break;
         case LogMsg::warn:  std::cerr << "Warning: "; break;
         case LogMsg::error: std::cerr << "Error: "; break;
         case LogMsg::mute:  assert(false);
