@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      exif.cpp
-  Version:   $Rev: 2453 $
+  Version:   $Rev: 3091 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: exif.cpp 2453 2011-02-13 14:08:44Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: exif.cpp 3091 2013-07-24 05:15:04Z robinwmills $")
 
 // *****************************************************************************
 // included header files
@@ -720,7 +720,8 @@ namespace Exiv2 {
                                                   emptyXmp,
                                                   Tag::root,
                                                   TiffMapping::findEncoder,
-                                                  header.get());
+                                                  header.get(),
+                                                  0);
         if (mio1.size() <= 65527) {
             append(blob, mio1.mmap(), mio1.size());
             return wm;
@@ -751,6 +752,11 @@ namespace Exiv2 {
             { pttLen, "Exif.Pentax.PreviewLength"                     },
             { pttTag, "Exif.Pentax.PreviewOffset"                     },
             { pttTag, "Exif.Pentax.PreviewResolution"                 },
+            { pttLen, "Exif.PentaxDng.PreviewLength"                  },
+            { pttTag, "Exif.PentaxDng.PreviewOffset"                  },
+            { pttTag, "Exif.PentaxDng.PreviewResolution"              },
+            { pttLen, "Exif.SamsungPreview.JPEGInterchangeFormatLength" },
+            { pttIfd, "SamsungPreview"                                },
             { pttLen, "Exif.Thumbnail.StripByteCounts"                },
             { pttIfd, "Thumbnail"                                     },
             { pttLen, "Exif.Thumbnail.JPEGInterchangeFormatLength"    },
@@ -817,11 +823,12 @@ namespace Exiv2 {
                                       emptyXmp,
                                       Tag::root,
                                       TiffMapping::findEncoder,
-                                      header.get());
+                                      header.get(),
+                                      0);
         append(blob, mio2.mmap(), mio2.size());
 #ifdef DEBUG
         if (wm == wmIntrusive) {
-            std::cerr << "SIZE OF EXIF DATA IS " << std::dec << io.size() << " BYTES\n";
+            std::cerr << "SIZE OF EXIF DATA IS " << std::dec << mio2.size() << " BYTES\n";
         }
         else {
             std::cerr << "SIZE DOESN'T MATTER, NON-INTRUSIVE WRITING USED\n";
