@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2010 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      futils.cpp
-  Version:   $Rev: 2286 $
+  Version:   $Rev: 3091 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   08-Dec-03, ahu: created
              02-Apr-05, ahu: moved to Exiv2 namespace
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: futils.cpp 2286 2010-06-27 10:04:39Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: futils.cpp 3091 2013-07-24 05:15:04Z robinwmills $")
 
 // *****************************************************************************
 // included header files
@@ -69,7 +69,7 @@ namespace Exiv2 {
     bool fileExists(const std::string& path, bool ct)
     {
         struct stat buf;
-		int ret = ::stat(path.c_str(), &buf);
+        int ret = ::stat(path.c_str(), &buf);
         if (0 != ret)                    return false;
         if (ct && !S_ISREG(buf.st_mode)) return false;
         return true;
@@ -104,6 +104,9 @@ namespace Exiv2 {
         strerror_r(error, buf, n);
 # endif
         os << buf;
+        // Issue# 908.
+        // report strerror() if strerror_r() returns empty
+        if ( !buf[0] ) os << strerror(error);
 #else
         os << std::strerror(error);
 #endif
