@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,13 +20,13 @@
  */
 /*
   File:      iptc.cpp
-  Version:   $Rev: 2455 $
+  Version:   $Rev: 3091 $
   Author(s): Brad Schick (brad) <brad@robotbattle.com>
   History:   31-July-04, brad: created
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: iptc.cpp 2455 2011-02-13 14:39:15Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: iptc.cpp 3091 2013-07-24 05:15:04Z robinwmills $")
 
 // *****************************************************************************
 // included header files
@@ -40,6 +40,7 @@ EXIV2_RCSID("@(#) $Id: iptc.cpp 2455 2011-02-13 14:39:15Z ahuggel $")
 // + standard includes
 #include <iostream>
 #include <algorithm>
+#include <iterator>
 
 // *****************************************************************************
 namespace {
@@ -469,13 +470,29 @@ namespace Exiv2 {
         return 0;
     } // IptcParser::decode
 
+    /*!
+      @brief Compare two iptc items by record. Return true if the record of
+             lhs is less than that of rhs.
+
+      This is a helper function for IptcParser::encode().
+     */
+    bool cmpIptcdataByRecord(const Iptcdatum& lhs, const Iptcdatum& rhs)
+    {
+        return lhs.record() < rhs.record();
+    }
+
     DataBuf IptcParser::encode(const IptcData& iptcData)
     {
         DataBuf buf(iptcData.size());
         byte *pWrite = buf.pData_;
 
-        IptcData::const_iterator iter = iptcData.begin();
-        IptcData::const_iterator end = iptcData.end();
+        // Copy the iptc data sets and sort them by record but preserve the order of datasets
+        IptcMetadata sortedIptcData;
+        std::copy(iptcData.begin(), iptcData.end(), std::back_inserter(sortedIptcData));
+        std::stable_sort(sortedIptcData.begin(), sortedIptcData.end(), cmpIptcdataByRecord);
+
+        IptcData::const_iterator iter = sortedIptcData.begin();
+        IptcData::const_iterator end = sortedIptcData.end();
         for ( ; iter != end; ++iter) {
             // marker, record Id, dataset num
             *pWrite++ = marker_;
