@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,7 +20,7 @@
  */
 /*
   File:      olympusmn.cpp
-  Version:   $Rev: 2453 $
+  Version:   $Rev: 3171 $
   Author(s): Will Stokes (wuz) <wstokes@gmail.com>
              Andreas Huggel (ahu) <ahuggel@gmx.net>
              Gilles Caulier (gc) <caulier dot gilles at gmail dot com>
@@ -31,7 +31,7 @@
 
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: olympusmn.cpp 2453 2011-02-13 14:08:44Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: olympusmn.cpp 3171 2013-09-22 10:06:21Z nkbj $")
 
 // *****************************************************************************
 // included header files
@@ -756,6 +756,7 @@ namespace Exiv2 {
         TagInfo(0x0302, "ExtenderSerialNumber", N_("Extender Serial Number"), N_("Extender serial number"), olympusEqId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0303, "ExtenderModel", N_("Extender Model"), N_("Extender model"), olympusEqId, makerTags, asciiString, -1, printValue),
         TagInfo(0x0304, "ExtenderFirmwareVersion", N_("Extender Firmware Version"), N_("Extender firmwareversion"), olympusEqId, makerTags, unsignedLong, -1, printValue),
+        TagInfo(0x0403, "ConversionLens", N_("Conversion Lens"), N_("Conversion lens"), olympusEqId, makerTags, asciiString, -1, printValue),
         TagInfo(0x1000, "FlashType", N_("Flash Type"), N_("Flash type"), olympusEqId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(olympusEqFlashType)),
         TagInfo(0x1001, "FlashModel", N_("Flash Model"), N_("Flash model"), olympusEqId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(olympusEqFlashModel)),
         TagInfo(0x1002, "FlashFirmwareVersion", N_("Flash Firmware Version"), N_("Flash firmware version"), olympusEqId, makerTags, unsignedLong, -1, printValue),
@@ -1004,7 +1005,7 @@ namespace Exiv2 {
         TagInfo(0x0301, "FocusStepCount", N_("Focus Step Count"), N_("Focus step count"), olympusFiId, makerTags, unsignedShort, -1, printValue),
         TagInfo(0x0303, "FocusStepInfinity", N_("Focus Step Infinity"), N_("Focus step infinity"), olympusFiId, makerTags, unsignedShort, -1, printValue),
         TagInfo(0x0304, "FocusStepNear", N_("Focus Step Near"), N_("Focus step near"), olympusFiId, makerTags, unsignedShort, -1, printValue),
-        TagInfo(0x0305, "FocusDistance", N_("Focus Distance"), N_("Focus distance"), olympusFiId, makerTags, unsignedRational, -1, printValue),
+        TagInfo(0x0305, "FocusDistance", N_("Focus Distance"), N_("Focus distance"), olympusFiId, makerTags, unsignedRational, -1, print0x0305),
         TagInfo(0x0308, "AFPoint", N_("AF Point"), N_("AF point"), olympusFiId, makerTags, unsignedShort, -1, print0x0308),
         TagInfo(0x1201, "ExternalFlash", N_("External Flash"), N_("External flash"), olympusFiId, makerTags, unsignedShort, -1, EXV_PRINT_TAG(olympusOffOn)),
         TagInfo(0x1203, "ExternalFlashGuideNumber", N_("External Flash Guide Number"), N_("External flash guide number"), olympusFiId, makerTags, signedRational, -1, printValue),
@@ -1237,57 +1238,98 @@ namespace Exiv2 {
             byte val[3];
             const char *label;
         } lensTypes[] = {
-            { { 0,  0,  0 }, N_("None")                                            },
-            { { 0,  1,  0 }, N_("Olympus Zuiko Digital ED 50mm F2.0 Macro")        },
-            { { 0,  1,  1 }, N_("Olympus Zuiko Digital 40-150mm F3.5-4.5")         },
-            { { 0,  1, 16 }, N_("Olympus Zuiko Digital ED 14-42mm F3.5-5.6")       },
-            { { 0,  2,  0 }, N_("Olympus Zuiko Digital ED 150mm F2.0")             },
-            { { 0,  2, 16 }, N_("Olympus Zuiko Digital 17mm F2.8 Pancake")         },
-            { { 0,  3,  0 }, N_("Olympus Zuiko Digital ED 300mm F2.8")             },
-            { { 0,  5,  0 }, N_("Olympus Zuiko Digital 14-54mm F2.8-3.5")          },
-            { { 0,  5,  1 }, N_("Olympus Zuiko Digital Pro ED 90-250mm F2.8")      },
-            { { 0,  6,  0 }, N_("Olympus Zuiko Digital ED 50-200mm F2.8-3.5")      },
-            { { 0,  6,  1 }, N_("Olympus Zuiko Digital ED 8mm F3.5 Fisheye")       },
-            { { 0,  7,  0 }, N_("Olympus Zuiko Digital 11-22mm F2.8-3.5")          },
-            { { 0,  7,  1 }, N_("Olympus Zuiko Digital 18-180mm F3.5-6.3")         },
-            { { 0,  8,  1 }, N_("Olympus Zuiko Digital 70-300mm F4.0-5.6")         },
-            { { 0, 21,  0 }, N_("Olympus Zuiko Digital ED 7-14mm F4.0")            },
-            { { 0, 23,  0 }, N_("Olympus Zuiko Digital Pro ED 35-100mm F2.0")      },
-            { { 0, 24,  0 }, N_("Olympus Zuiko Digital 14-45mm F3.5-5.6")          },
-            { { 0, 32,  0 }, N_("Olympus Zuiko Digital 35mm F3.5 Macro")           },
-            { { 0, 34,  0 }, N_("Olympus Zuiko Digital 17.5-45mm F3.5-5.6")        },
-            { { 0, 35,  0 }, N_("Olympus Zuiko Digital ED 14-42mm F3.5-5.6")       },
-            { { 0, 36,  0 }, N_("Olympus Zuiko Digital ED 40-150mm F4.0-5.6")      },
-            { { 0, 48,  0 }, N_("Olympus Zuiko Digital ED 50-200mm F2.8-3.5 SWD")  },
-            { { 0, 49,  0 }, N_("Olympus Zuiko Digital ED 12-60mm F2.8-4.0 SWD")   },
-            { { 0, 50,  0 }, N_("Olympus Zuiko Digital ED 14-35mm F2.0 SWD")       },
-            { { 0, 51,  0 }, N_("Olympus Zuiko Digital 25mm F2.8")                 },
-            { { 0, 52,  0 }, N_("Olympus Zuiko Digital ED 9-18mm F4.0-5.6")        },
-            { { 0, 53,  0 }, N_("Olympus Zuiko Digital 14-54mm F2.8-3.5 II")       },
-            { { 1,  1,  0 }, N_("Sigma 18-50mm F3.5-5.6")                          },
-            { { 1,  2,  0 }, N_("Sigma 55-200mm F4.0-5.6 DC")                      },
-            { { 1,  3,  0 }, N_("Sigma 18-125mm F3.5-5.6 DC")                      },
-            { { 1,  4,  0 }, N_("Sigma 18-125mm F3.5-5.6")                         },
-            { { 1,  5,  0 }, N_("Sigma 30mm F1.4")                                 },
-            { { 1,  6,  0 }, N_("Sigma 50-500mm F4.0-6.3 EX DG APO HSM RF")        },
-            { { 1,  7,  0 }, N_("Sigma 105mm F2.8 DG")                             },
-            { { 1,  8,  0 }, N_("Sigma 150mm F2.8 DG HSM")                         },
-            { { 1, 16,  0 }, N_("Sigma 24mm F1.8 EX DG Aspherical Macro")          },
-            { { 1, 17,  0 }, N_("Sigma 135-400mm F4.5-5.6 DG ASP APO RF")          },
-            { { 1, 18,  0 }, N_("Sigma 300-800mm F5.6 EX DG APO")                  },
-            { { 1, 20,  0 }, N_("Sigma 50-500mm F4.0-6.3 EX DG APO HSM RF")        },
-            { { 1, 21,  0 }, N_("Sigma 10-20mm F4.0-5.6 EX DC HSM")                },
-            { { 2,  1,  0 }, N_("Leica D Vario Elmarit 14-50mm F2.8-3.5 Asph.")    },
-            { { 2,  1, 16 }, N_("Lumix G Vario 14-45mm F3.5-5.6 Asph. Mega OIS")   },
-            { { 2,  2,  0 }, N_("Leica D Summilux 25mm F1.4 Asph.")                },
-            { { 2,  2, 16 }, N_("Lumix G Vario 45-200mm F4-5.6 Mega OIS")          },
-            { { 2,  3,  1 }, N_("Leica D Vario Elmar 14-50mm F3.8-5.6 Asph.")      },
-            { { 2,  3, 16 }, N_("Lumix G Vario HD 14-140mm F4-5.8 Asph. Mega OIS") },
-            { { 2,  4,  0 }, N_("Leica D Vario Elmar 14-150mm F3.5-5.6")           },
-            { { 2,  4, 16 }, N_("Lumix G Vario 7-14mm F4 Asph.")                   },
-            { { 2,  5, 16 }, N_("Lumix G 20mm F1.7 Asph.")                         },
-            { { 3,  1,  0 }, N_("Leica D Vario Elmarit 14-50mm F2.8-3.5 Asph.")    },
-            { { 3,  2,  0 }, N_("Leica D Summilux 25mm F1.4 Asph.")                },
+            { { 0,  0,  0 }, N_("None")                                                 },
+            { { 0,  1,  0 }, N_("Olympus Zuiko Digital ED 50mm F2.0 Macro")             },
+            { { 0,  1,  1 }, N_("Olympus Zuiko Digital 40-150mm F3.5-4.5")              },
+            { { 0,  1, 16 }, N_("Olympus M.Zuiko Digital ED 14-42mm F3.5-5.6")          },
+            { { 0,  2,  0 }, N_("Olympus Zuiko Digital ED 150mm F2.0")                  },
+            { { 0,  2, 16 }, N_("Olympus M.Zuiko Digital 17mm F2.8 Pancake")            },
+            { { 0,  3,  0 }, N_("Olympus Zuiko Digital ED 300mm F2.8")                  },
+            { { 0,  3, 16 }, N_("Olympus M.Zuiko Digital ED 14-150mm F4.0-5.6")         },
+            { { 0,  4, 16 }, N_("Olympus M.Zuiko Digital ED 9-18mm F4.0-5.6")           },
+            { { 0,  5,  0 }, N_("Olympus Zuiko Digital 14-54mm F2.8-3.5")               },
+            { { 0,  5,  1 }, N_("Olympus Zuiko Digital Pro ED 90-250mm F2.8")           },
+            { { 0,  5, 16 }, N_("Olympus M.Zuiko Digital ED 14-42mm F3.5-5.6 L")        },
+            { { 0,  6,  0 }, N_("Olympus Zuiko Digital ED 50-200mm F2.8-3.5")           },
+            { { 0,  6,  1 }, N_("Olympus Zuiko Digital ED 8mm F3.5 Fisheye")            },
+            { { 0,  6, 16 }, N_("Olympus M.Zuiko Digital ED 40-150mm F4.0-5.6")         },
+            { { 0,  7,  0 }, N_("Olympus Zuiko Digital 11-22mm F2.8-3.5")               },
+            { { 0,  7,  1 }, N_("Olympus Zuiko Digital 18-180mm F3.5-6.3")              },
+            { { 0,  7, 16 }, N_("Olympus M.Zuiko Digital ED 12mm F2.0")                 },
+            { { 0,  8,  1 }, N_("Olympus Zuiko Digital 70-300mm F4.0-5.6")              },
+            { { 0,  8, 16 }, N_("Olympus M.Zuiko Digital ED 75-300mm F4.8-6.7")         },
+            { { 0,  9, 16 }, N_("Olympus M.Zuiko Digital 14-42mm F3.5-5.6 II")          },
+            { { 0, 16,  1 }, N_("Kenko Tokina Reflex 300mm F6.3 MF Macro")              },
+            { { 0, 16, 16 }, N_("Olympus M.Zuiko Digital ED 12-50mm F3.5-6.3 EZ")       },
+            { { 0, 17, 16 }, N_("Olympus M.Zuiko Digital 45mm F1.8")                    },
+            { { 0, 18, 16 }, N_("Olympus M.Zuiko Digital ED 60mm F2.8 Macro")           },
+            { { 0, 19, 16 }, N_("Olympus M.Zuiko Digital ED 14-42mm F3.5-5.6 II R")     },
+            { { 0, 20, 16 }, N_("Olympus M.Zuiko Digital ED 40-150mm F4.0-5.6 R")       },
+            { { 0, 21,  0 }, N_("Olympus Zuiko Digital ED 7-14mm F4.0")                 },
+            { { 0, 21, 16 }, N_("Olympus M.Zuiko Digital ED 75mm F1.8")                 },
+            { { 0, 22, 16 }, N_("Olympus M.Zuiko Digital 17mm F1.8")                    },
+            { { 0, 23,  0 }, N_("Olympus Zuiko Digital Pro ED 35-100mm F2.0")           },
+            { { 0, 24,  0 }, N_("Olympus Zuiko Digital 14-45mm F3.5-5.6")               },
+            { { 0, 24, 16 }, N_("Olympus M.Zuiko Digital ED 75-300mm F4.8-6.7 II")      },
+            { { 0, 25, 16 }, N_("Olympus M.Zuiko Digital ED 12-40mm F2.8 Pro")          },
+            { { 0, 32,  0 }, N_("Olympus Zuiko Digital 35mm F3.5 Macro")                },
+            { { 0, 34,  0 }, N_("Olympus Zuiko Digital 17.5-45mm F3.5-5.6")             },
+            { { 0, 35,  0 }, N_("Olympus Zuiko Digital ED 14-42mm F3.5-5.6")            },
+            { { 0, 36,  0 }, N_("Olympus Zuiko Digital ED 40-150mm F4.0-5.6")           },
+            { { 0, 48,  0 }, N_("Olympus Zuiko Digital ED 50-200mm F2.8-3.5 SWD")       },
+            { { 0, 49,  0 }, N_("Olympus Zuiko Digital ED 12-60mm F2.8-4.0 SWD")        },
+            { { 0, 50,  0 }, N_("Olympus Zuiko Digital ED 14-35mm F2.0 SWD")            },
+            { { 0, 51,  0 }, N_("Olympus Zuiko Digital 25mm F2.8")                      },
+            { { 0, 52,  0 }, N_("Olympus Zuiko Digital ED 9-18mm F4.0-5.6")             },
+            { { 0, 53,  0 }, N_("Olympus Zuiko Digital 14-54mm F2.8-3.5 II")            },
+            { { 1,  1,  0 }, N_("Sigma 18-50mm F3.5-5.6 DC")                            },
+            { { 1,  1, 16 }, N_("Sigma 30mm F2.8 EX DN")                                },
+            { { 1,  2,  0 }, N_("Sigma 55-200mm F4.0-5.6 DC")                           },
+            { { 1,  2, 16 }, N_("Sigma 19mm F2.8 EX DN")                                },
+            { { 1,  3,  0 }, N_("Sigma 18-125mm F3.5-5.6 DC")                           },
+            { { 1,  3, 16 }, N_("Sigma 30mm F2.8 DN | A")                               },
+            { { 1,  4,  0 }, N_("Sigma 18-125mm F3.5-5.6")                              },
+            { { 1,  4, 16 }, N_("Sigma 19mm F2.8 DN | A")                               },
+            { { 1,  5,  0 }, N_("Sigma 30mm F1.4")                                      },
+            { { 1,  5, 16 }, N_("Sigma 60mm F2.8 DN | A")                               },
+            { { 1,  6,  0 }, N_("Sigma 50-500mm F4.0-6.3 EX DG APO HSM RF")             },
+            { { 1,  7,  0 }, N_("Sigma 105mm F2.8 DG")                                  },
+            { { 1,  8,  0 }, N_("Sigma 150mm F2.8 DG HSM")                              },
+            { { 1,  9,  0 }, N_("Sigma 18-50mm F2.8 EX DC Macro")                       },
+            { { 1, 16,  0 }, N_("Sigma 24mm F1.8 EX DG Aspherical Macro")               },
+            { { 1, 17,  0 }, N_("Sigma 135-400mm F4.5-5.6 DG ASP APO RF")               },
+            { { 1, 18,  0 }, N_("Sigma 300-800mm F5.6 EX DG APO")                       },
+            { { 1, 19,  0 }, N_("Sigma 30mm F1.4 EX DC HSM")                            },
+            { { 1, 20,  0 }, N_("Sigma 50-500mm F4.0-6.3 EX DG APO HSM RF")             },
+            { { 1, 21,  0 }, N_("Sigma 10-20mm F4.0-5.6 EX DC HSM")                     },
+            { { 1, 22,  0 }, N_("Sigma 70-200mm F2.8 EX DG Macro HSM II")               },
+            { { 1, 23,  0 }, N_("Sigma 50mm F1.4 EX DG HSM")                            },
+            { { 2,  1,  0 }, N_("Leica D Vario Elmarit 14-50mm F2.8-3.5 Asph.")         },
+            { { 2,  1, 16 }, N_("Lumix G Vario 14-45mm F3.5-5.6 Asph. Mega OIS")        },
+            { { 2,  2,  0 }, N_("Leica D Summilux 25mm F1.4 Asph.")                     },
+            { { 2,  2, 16 }, N_("Lumix G Vario 45-200mm F4.0-5.6 Mega OIS")             },
+            { { 2,  3,  0 }, N_("Leica D Vario Elmar 14-50mm F3.8-5.6 Asph. Mega OIS")  },
+            { { 2,  3,  1 }, N_("Leica D Vario Elmar 14-50mm F3.8-5.6 Asph.")           },
+            { { 2,  3, 16 }, N_("Lumix G Vario HD 14-140mm F4.0-5.8 Asph. Mega OIS")    },
+            { { 2,  4,  0 }, N_("Leica D Vario Elmar 14-150mm F3.5-5.6")                },
+            { { 2,  4, 16 }, N_("Lumix G Vario 7-14mm F4.0 Asph.")                      },
+            { { 2,  5, 16 }, N_("Lumix G 20mm F1.7 Asph.")                              },
+            { { 2,  6, 16 }, N_("Leica DG Macro-Elmarit 45mm F2.8 Asph. Mega OIS")      },
+            { { 2,  7, 16 }, N_("Lumix G Vario 14-42mm F3.5-5.6 Asph. Mega OIS")        },
+            { { 2,  8, 16 }, N_("Lumix G Fisheye 8mm F3.5")                             },
+            { { 2,  9, 16 }, N_("Lumix G Vario 100-300mm F4.0-5.6 Mega OIS")            },
+            { { 2, 16, 16 }, N_("Lumix G 14mm F2.5 Asph.")                              },
+            { { 2, 17, 16 }, N_("Lumix G 3D 12.5mm F12")                                },
+            { { 2, 18, 16 }, N_("Leica DG Summilux 25mm F1.4 Asph.")                    },
+            { { 2, 19, 16 }, N_("Lumix G X Vario PZ 45-175mm F4.0-5.6 Asph. Power OIS") },
+            { { 2, 20, 16 }, N_("Lumix G X Vario PZ 14-42mm F3.5-5.6 Asph. Power OIS")  },
+            { { 2, 21, 16 }, N_("Lumix G X Vario 12-35mm F2.8 Asph. Power OIS")         },
+            { { 2, 22, 16 }, N_("Lumix G Vario 45-150mm F4.0-5.6 Asph. Mega OIS")       },
+            { { 2, 23, 16 }, N_("Lumix G X Vario 35-100mm F2.8 Power OIS")              },
+            { { 2, 24, 16 }, N_("Lumix G Vario 14-42mm F3.5-5.6 II Asph. Mega OIS")     },
+            { { 2, 25, 16 }, N_("Lumix G Vario 14-140mm F3.5-5.6 Asph. Power OIS")      },
+            { { 3,  1,  0 }, N_("Leica D Vario Elmarit 14-50mm F2.8-3.5 Asph.")         },
+            { { 3,  2,  0 }, N_("Leica D Summilux 25mm F1.4 Asph.")                     },
             // End of list marker
             { { 0xff,  0,  0 }, "" }
         };
@@ -1478,6 +1520,26 @@ namespace Exiv2 {
         return os;
     } // OlympusMakerNote::print0x1209
 
+    // Olympus FocusDistance 0x0305
+    std::ostream& OlympusMakerNote::print0x0305(std::ostream& os, const Value& value, const ExifData*) {
+        if (value.count() != 1 || value.typeId() != unsignedRational) {
+            return os << value;
+        }
+        
+        Rational distance = value.toRational();
+        if(static_cast<uint32_t>(distance.first) == 0xffffffff) {
+            os << _("Infinity");
+        }
+        else {
+            std::ostringstream oss;
+            oss.copyfmt(os);
+            os << std::fixed << std::setprecision(2);
+            os << (float)distance.first/1000 << " m";
+            os.copyfmt(oss); 
+        }
+        return os;
+    }
+    
     // Olympus FocusInfo tag 0x0308 AFPoint
     std::ostream& OlympusMakerNote::print0x0308(std::ostream& os, const Value&
 value, const ExifData* metadata)
