@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2010 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      rafimage.cpp
-  Version:   $Rev: 2286 $
+  Version:   $Rev: 3091 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   05-Feb-07, ahu: created
   Credits:   See header file
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: rafimage.cpp 2286 2010-06-27 10:04:39Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: rafimage.cpp 3091 2013-07-24 05:15:04Z robinwmills $")
 
 // *****************************************************************************
 // included header files
@@ -55,7 +55,7 @@ EXIV2_RCSID("@(#) $Id: rafimage.cpp 2286 2010-06-27 10:04:39Z ahuggel $")
 namespace Exiv2 {
 
     RafImage::RafImage(BasicIo::AutoPtr io, bool /*create*/)
-        : Image(ImageType::raf, mdExif | mdIptc, io)
+        : Image(ImageType::raf, mdExif | mdIptc | mdXmp, io)
     {
     } // RafImage::RafImage
 
