@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -26,7 +26,7 @@
   This is a simplified version of the ACE_RCSID macro that is used in the
   <a href="http://www.cs.wustl.edu/~schmidt/ACE.html">ACE(TM)</a> distribution.
 
-  @version $Rev: 2453 $
+  @version $Rev: 3201 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    02-Feb-04, ahu: created
@@ -52,11 +52,16 @@
          -# To avoid warnings of the type "variable declared and never used".
 
  */
+
+#if (defined(__GNUG__) || defined(__GNUC__) || defined (_MSC_VER))  && ! defined(__clang__)
 #define EXIV2_RCSID(id) \
     namespace { \
         inline const char* getRcsId(const char*) { return id ; } \
         const char* rcsId = getRcsId(rcsId); \
     }
+#else
+#define EXIV2_RCSID(id)
+#endif
 
 #endif // #if !defined (EXIV2_RCSID)
 #endif // #ifndef RCSID_INT_HPP_
