@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,13 +20,13 @@
  */
 /*
   File:      sonymn.cpp
-  Version:   $Rev: 2455 $
+  Version:   $Rev: 3201 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   18-Apr-05, ahu: created
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: sonymn.cpp 2455 2011-02-13 14:39:15Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: sonymn.cpp 3201 2013-12-01 12:13:42Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -64,28 +64,61 @@ namespace Exiv2 {
 
     //! Lookup table to translate Sony model ID values to readable labels
     extern const TagDetails sonyModelId[] = {
-        { 2,   "DSC-R1"    },
-        { 256, "DSLR-A100" },
-        { 257, "DSLR-A900" },
-        { 258, "DSLR-A700" },
-        { 259, "DSLR-A200" },
-        { 260, "DSLR-A350" },
-        { 261, "DSLR-A300" },
-        { 263, "DSLR-A380" },
-        { 264, "DSLR-A330" },
-        { 265, "DSLR-A230" },
-        { 269, "DSLR-A850" },
-        { 273, "DSLR-A550" },
-        { 274, "DSLR-A500" },
-        { 275, "DSLR-A450" },
-        { 278, "NEX-5"     },
-        { 279, "NEX-3"     }
+        { 2, "DSC-R1"                   },
+        { 256, "DSLR-A100"              },
+        { 257, "DSLR-A900"              },
+        { 258, "DSLR-A700"              },
+        { 259, "DSLR-A200"              },
+        { 260, "DSLR-A350"              },
+        { 261, "DSLR-A300"              },
+        { 262, "DSLR-A900 (APS-C mode)" },
+        { 263, "DSLR-A380/A390"         },
+        { 264, "DSLR-A330"              },
+        { 265, "DSLR-A230"              },
+        { 266, "DSLR-A290"              },
+        { 269, "DSLR-A850"              },
+        { 270, "DSLR-A850 (APS-C mode)" },
+        { 273, "DSLR-A550"              },
+        { 274, "DSLR-A500"              },
+        { 275, "DSLR-A450"              },
+        { 278, "NEX-5"                  },
+        { 279, "NEX-3"                  },
+        { 280, "SLT-A33"                },
+        { 281, "SLT-A55 / SLT-A55V"     },
+        { 282, "DSLR-A560"              },
+        { 283, "DSLR-A580"              },
+        { 284, "NEX-C3"                 },
+        { 285, "SLT-A35"                },
+        { 286, "SLT-A65 / SLT-A65V"     },
+        { 287, "SLT-A77 / SLT-A77V"     },
+        { 288, "NEX-5N"                 },
+        { 289, "NEX-7"                  },
+        { 290, "NEX-VG20E"              },
+        { 291, "SLT-A37"                },
+        { 292, "SLT-A57"                },
+        { 293, "NEX-F3"                 },
+        { 294, "SLT-A99 / SLT-A99V"     },
+        { 295, "NEX-6"                  },
+        { 296, "NEX-5R"                 },
+        { 297, "DSC-RX100"              },
+        { 298, "DSC-RX1"                },
+        { 299, "NEX-VG900"              },
+        { 300, "NEX-VG30E"              },
+        { 302, "ILCE-3000"              },
+        { 303, "SLT-A58"                },
+        { 305, "NEX-3N"                 },
+        { 306, "ILCE-7"                 },
+        { 307, "NEX-5T"                 },
+        { 308, "DSC-RX100M2"            },
+        { 309, "DSC-RX10"               },
+        { 310, "DSC-RX1R"               },
+        { 311, "ILCE-7R"                }
     };
 
     //! Lookup table to translate Sony dynamic range optimizer values to readable labels
     extern const TagDetails print0xb025[] = {
         { 0,  N_("Off")           },
-        { 1,  N_("Standard ")     },
+        { 1,  N_("Standard")      },
         { 2,  N_("Advanced Auto") },
         { 3,  N_("Auto")          },
         { 8,  N_("Advanced Lv1")  },
@@ -105,35 +138,42 @@ namespace Exiv2 {
         { 0,     N_("Auto")                     },
         { 1,     N_("Portrait")                 },
         { 2,     N_("Beach")                    },
+        { 3,     N_("Sports")                   },
         { 4,     N_("Snow")                     },
-        { 5,     N_("Landscape ")               },
+        { 5,     N_("Landscape")                },
         { 6,     N_("Program")                  },
         { 7,     N_("Aperture priority")        },
         { 8,     N_("Shutter priority")         },
         { 9,     N_("Night Scene / Twilight")   },
         { 10,    N_("Hi-Speed Shutter")         },
         { 11,    N_("Twilight Portrait")        },
-        { 12,    N_("Soft Snap")                },
+        { 12,    N_("Soft Snap / Portrait")     },
         { 13,    N_("Fireworks")                },
         { 14,    N_("Smile Shutter")            },
         { 15,    N_("Manual")                   },
         { 18,    N_("High Sensitivity")         },
+        { 19,    N_("Macro")                    },
         { 20,    N_("Advanced Sports Shooting") },
         { 29,    N_("Underwater")               },
-        { 33,    N_("Gourmet")                  },
-        { 34,    N_("Panorama")                 },
-        { 35,    N_("Handheld Twilight")        },
+        { 33,    N_("Food")                     },
+        { 34,    N_("Sweep Panorama")           },
+        { 35,    N_("Handheld Night Shot")      },
         { 36,    N_("Anti Motion Blur")         },
         { 37,    N_("Pet")                      },
         { 38,    N_("Backlight Correction HDR") },
+        { 39,    N_("Superior Auto")            },
+        { 40,    N_("Background Defocus")       },
+        { 41,    N_("Soft Skin")                },
+        { 42,    N_("3D Image")                 },
         { 65535, N_("n/a")                      }
     };
 
     //! Lookup table to translate Sony JPEG Quality values to readable labels
     extern const TagDetails sonyJPEGQuality[] = {
-        { 0,     N_("Normal") },
-        { 1,     N_("Fine")   },
-        { 65535, N_("n/a")    }
+        { 0,     N_("Normal")       },
+        { 1,     N_("Fine")         },
+        { 2,     N_("Extra Fine")   },
+        { 65535, N_("n/a")          }
     };
 
     //! Lookup table to translate Sony anti-blur values to readable labels
@@ -167,6 +207,8 @@ namespace Exiv2 {
         { 7,  N_("White Flourescent")          },
         { 8,  N_("Cool White Flourescent")     },
         { 9,  N_("Day White Flourescent")      },
+        { 10, N_("Incandescent2")              },
+        { 11, N_("Warm White Fluorescent")     }, 
         { 14, N_("Incandescent")               },
         { 15, N_("Flash")                      },
         { 17, N_("Underwater 1 (Blue Water)")  },
