@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,13 +20,13 @@
  */
 /*
   File:      tiffvisitor.cpp
-  Version:   $Rev: 2453 $
+  Version:   $Rev: 3201 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   11-Apr-06, ahu: created
  */
 // *****************************************************************************
 #include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id: tiffvisitor.cpp 2453 2011-02-13 14:08:44Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: tiffvisitor.cpp 3201 2013-12-01 12:13:42Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -820,10 +820,6 @@ namespace Exiv2 {
     {
         assert(object != 0);
 
-        // Skip image tags of existing TIFF image - they were copied earlier -
-        // but add and encode image tags of new images (creation)
-        if (isImageTag(object->tag(), object->group())) return;
-
         ExifData::iterator pos = exifData_.end();
         const Exifdatum* ed = datum;
         if (ed == 0) {
@@ -855,7 +851,9 @@ namespace Exiv2 {
             // duplicate tags
             object->idx_ = ed->idx();
         }
-        if (ed) {
+        // Skip encoding image tags of existing TIFF image - they were copied earlier -
+        // but encode image tags of new images (creation)
+        if (ed && !isImageTag(object->tag(), object->group())) {
             const EncoderFct fct = findEncoderFct_(make_, object->tag(), object->group());
             if (fct) {
                 // If an encoding function is registered for the tag, use it
@@ -1165,9 +1163,9 @@ namespace Exiv2 {
     void TiffReader::changeState(TiffRwState::AutoPtr state)
     {
         if (state.get() != 0) {
-            if (pOrigState_ != pState_) delete pState_;
             // invalidByteOrder indicates 'no change'
             if (state->byteOrder_ == invalidByteOrder) state->byteOrder_ = pState_->byteOrder_;
+            if (pOrigState_ != pState_) delete pState_;
             pState_ = state.release();
         }
     }
@@ -1523,10 +1521,9 @@ namespace Exiv2 {
                           << ", exceeds buffer size by "
                           // cast to make MSVC happy
                           << static_cast<uint32_t>(pData + size - pLast_)
-                          << " Bytes; adjusting the size\n";
+                          << " Bytes; truncating the entry\n";
 #endif
-                size = static_cast<uint32_t>(pLast_ - pData);
-                // Todo: adjust count, make size a multiple of typeSize
+                size = 0;
             }
         }
         Value::AutoPtr v = Value::create(typeId);
